#!/usr/bin/env python
# -*- coding: utf-8 -*-
import sys
from optparse import OptionParser
import io, conv_table, details

__doc__ = """Tagset+represenation converter for Polish. Reads XCES
morph.xml-like input files assuming the KIPI tagset, produces TEI-like
disambiguated output with MTE tagset.

Information on usage will be displayed when run whith no arguments.
When used as a library, it seems better to use conv_table module directly
(consult process_file function from here and mte_extrakt module to get examples
of such uses).

NOTE: the implementation of the KIPI/XCES XML reader (io module) is rudimentary.
It makes many invalid assumptions about the structure of the input XML file:
the presence and absence of new line characters, not handling fancy XML stuff
like PCDATA blocks. It should work well with the output of TaKIPI tagger, but
it is not guaranteed to handle any other XCES-compliant file.


The converter is licensed under GNU LGPL 3.0 (the licence is in lgpl-3.0.txt).
The conversion tables are provided as machine-readable files (*.tab) and are part
of the converter source code (therefore the same licence applies).

MTE specifications for Polish: Natalia Kotsyba, Ivan Derzhanski, Adam Radziszewski, 06.08.2009
Conversion tables: Natalia Kotsyba, 06.09.2009
Converter code: Adam Radziszewski, 06.09.2009
"""

def _add_choice(parser, str1, str2, opt, dest, help):
	default = opt[0][0]
	mapped = dict(opt)
	parser.add_option(str1, str2, choices=mapped.keys(), default=default, dest = dest, help = help)
	
def go():
	"Runs the program."
	descr = '%prog INPUT_FILE [options]\n\n'
	parser = OptionParser(usage=descr)
	parser.add_option('-o', '--out', type='string', action='store', default = '', dest='output', help='output filename')
	_add_choice(parser, '-d', '--disamb-selection', details.Details.SELECT_DISAMB, 'select', 'disamb tag selection method')
	_add_choice(parser, '-n', '--text-naming', details.Details.TEXT_ID, 'textid', 'text name generation method')
	parser.add_option('-a', '--leave-ambiguities', action='store_false', default=True, dest='clean_lex',
		help='preserve ambiguity info in output')
	
	(options, args) = parser.parse_args()
	if len(args) != 1:
		print 'You need to provide an input file (morph.xml-like)'
		print
		parser.print_help()
		sys.exit(1)
	
	in_fname = args[0]
	out_fname = options.output
	
	converter = conv_table.Converter()
	process_file(converter, in_fname, out_fname, details.Details(options))

def process_file(converter, in_fname, out_fname, ds):
	"Processes a single file reusing once initialised converter."
	if not out_fname:
		out_fname = in_fname + '.convd'
	
	input = io.from_xces(in_fname, ds)
	output = io.to_tei(out_fname, ds)
	output(converter.process(input))

if __name__ == '__main__':
	go()
